"""Top-level package for startup."""

__author__ = """Robert van Straalen"""
__email__ = 'tech@datasciencelab.nl'
__version__ = '0.1.3'
